(function () {
    "use strict";

    var ExchangeApiLink = "https://shamra.sy/exchange/api/currencies";

    //Execute the logic of Exchange bundle
    displayExchange();

    var config = {};

    /**
     * The logic of the Exchange Bundle
     * @returns {undefined}
     */
    function displayExchange() {
        //Get the current script so we can fetch client data
        var currentScript = getCurrentScript();
        /**
         * Get the client configuration:
         *      the token of the client in the attribute 'data-token'
         *      the widget id in the attribute 'data-target'
         * @type {{token: string|null, target: (string)}}
         */
        config = {
            token: currentScript.getAttribute('data-token'),
            target: currentScript.getAttribute('data-target') || 'shamra-exchange-widget',
            source: currentScript.getAttribute('data-source') || 'pm',
            currencies: currentScript.getAttribute('data-currencies') || 'all'
        };
        //Get all validation errors and print them inside the console
        var validationResult = validateConfiguration();
        if (validationResult.length > 0) {
            for (var i = 0; i < validationResult.length; i++) {
                console.error(validationResult[i]);
            }
            displayErrorBeforeLoad(config.target);
            return undefined;
        }
        config.token = config.token.trim();
        config.target = config.target.trim();
        config.source = config.source.trim();
        config.currencies = config.currencies.trim();
        //Requesting data from Shamra Exchange API
        requestData();
    }


    /**
     * Function that gets the current script tag at the clients page so that we can fetch data attributes
     * @return Current script element
     */
    function getCurrentScript() {
        /**
         * The document.currentScript is supported in all browsers except IE,
         * so if the client is using IE, we fetch it using the logic in the getCurrentScriptForIE() function
         */
        if (!document.currentScript) {
            document.currentScript = getCurrentScriptForIE();
        }
        return document.currentScript;
    }

    /**
     *
     * @return {Node}
     */
    function getCurrentScriptForIE() {
        //Get all scripts loaded for this moment
        var scripts = document.getElementsByTagName('script');
        //Return the last loaded one, which is this script
        return scripts[scripts.length - 1];
    }

    /**
     * Function validates that the token and the target element id are set
     *
     * @returns {Array}
     */
    function validateConfiguration() {
        //Errors array to be returned
        var errors = [];
        //If the token is null or empty
        if (!(config.token)) {
            errors.push('Your token is empty or not set, please check our documentation!');
        }
        //If the target is null or empty
        if (!(config.target)) {
            errors.push('Your target element is empty or not set, please check our documentation!');
        }
        //If the source is null or empty or not one of "cdn" or "pm"
        if (!(config.source)) {
            errors.push('Your source is empty or not set, please check our documentation!');
        }else{
            if(!(config.source === "cbn" || config.source === "pm" || config.source === "both")){
                errors.push('Your source should be one of "cdn", "both" or "pm" , please check our documentation!')
            }
        }
        return errors;
    }

    /**
     * Function that requests exchange data from Shamra Exchange API
     */
    function requestData() {
        var xmlhttp;
        if (window.XMLHttpRequest) {
            //This code is for all browsers except IE
            xmlhttp = new XMLHttpRequest();
        } else {
            //This code is for IE
            xmlhttp = new ActiveXObject("Microsoft.XMLHTTP");
        }
        var ApiLink = ExchangeApiLink;
        var targetId = config.target;
        var token = config.token;
        var source = config.source;
        var currencies = config.currencies;
        xmlhttp.onreadystatechange = function () {
            if(this.readyState === 4) {
                if (this.status === 200) {
                    receiveExchangeData(this.responseText, targetId , source, ApiLink, token);
                } else if (this.status === 401) {
                    console.error('It seems like there was an error with your authentication, please check that your token { ' + token + ' } is correct!');
                    displayErrorBeforeDetectingTarget(targetId);
                } else if (this.status === 405 || this.status === 500) {
                    console.error('Sorry! we are having some defficulties!');
                    displayErrorBeforeDetectingTarget(targetId);
                } else {
                    console.error('An error occured, please check your configuration at Shamra Exchange, status code {' + this.status + '}');
                    displayErrorBeforeDetectingTarget(targetId);
                }
            }else if(this.readyState === 0){
                console.error('An error occured during the initiating of the request!');
                displayErrorBeforeDetectingTarget(targetId);
            }
        };
        xmlhttp.open("GET", ApiLink + '?token=' + token + '&source=' + source + '&currencies=' + currencies, true);
        xmlhttp.setRequestHeader('Accept' , 'application/json');
        try {
            if(window.addEventListener){
                window.addEventListener('load', function(){xmlhttp.send();})
            }else{
                window.attachEvent('onload', function(){xmlhttp.send();})
            }
        }catch(e) {
            //alert('An unknown error occurred!');
            displayErrorBeforeLoad(targetId);
        }
    }

    /**
     * Format the received data from the api and prepare it for display
     * @param requestResult
     * @param targetId
     * @param source
     * @param ApiLink
     * @param token
     */
    function receiveExchangeData(requestResult , targetId, source, ApiLink, token) {
        //the following three lines are for testing purposes
        var testingElement = document.getElementById('received');
        if(!!testingElement){
            testingElement.innerText = requestResult;
        }
        //If the target element wasn't found, notify the user
        var targetElement = document.getElementById(targetId);
        if(!!targetElement){
            targetElement.style.direction = 'rtl';
            targetElement.style.textAlign = 'center';
            //targetElement.innerHTML = requestResult;
            //Checking if the received data has a JSON format
            try {
                var receivedData = JSON.parse(requestResult);
                var labels = receivedData.labels;
                var data = receivedData.data;
                displayReceivedData(labels , data , targetElement, source, ApiLink, token)
            }catch (e){
                console.error('The received data seems to bee curropted, try again later!');
                displayError(targetElement);
            }
        }else{
            console.error('Shamra exchange API can\'t find the element with the id { ' + targetId + ' }');
        }
    }

    /**
     * Display the received data in the selected div
     *
     * @param labels
     * @param data
     * @param targetElement
     * @param source
     * @param ApiLink
     * @param token
     */
    function displayReceivedData(labels , data , targetElement, source, ApiLink, token) {
        ceateStyleTag();
        targetElement.innerHTML = '';
        targetElement.style.fontFamily = "'Cairo', sans-serif";
        var shamraLogoDiv = document.createElement('div');
        shamraLogoDiv.id = "shamra-logo-div";
        var logoImage = document.createElement('img');
        logoImage.id = "shamra-logo-image";
        logoImage.src = "https://shamra.sy/img/shamra.svg";
        logoImage.align = "middle";
        logoImage.onclick = function () {
            var win = window.open('https://shamra.sy/exchange?', '_blank');
            win.focus();
        };
        var headerText = document.createElement('span');
        headerText.appendChild(document.createTextNode("العملات من شمرا"));
        headerText.onclick = function () {
            var win = window.open('https://shamra.sy/exchange?', '_blank');
            win.focus();
        };
        shamraLogoDiv.appendChild(logoImage);
        shamraLogoDiv.appendChild(headerText);
        targetElement.appendChild(shamraLogoDiv);
        if(source !== 'both'){
            var table = document.createElement('table');
            table.classList.add('exchange-api-table');
            table.cellSpacing = 0;
            table.appendChild(getCreatedTableHeaders(labels));
            for(var dataElement in data){
                table.appendChild(getCreatedTableRow(data[dataElement] , source , ApiLink, token));
            }
            targetElement.appendChild(table);
        }else{
            var tabsDiv = document.createElement('div');
            tabsDiv.id = 'shamra-tabs-div';
            var cbTab = document.createElement('a');
            cbTab.id = "shamra-tab-cb";
            cbTab.classList.add('shamra-tab');
            cbTab.classList.add('active');
            cbTab.innerText = labels.cbn_label;
            cbTab.onclick = function (e) {
		e.preventDefault();
                this.classList.add('active');
                document.getElementById('shamra-tab-pm').classList.remove('active');
                document.getElementById('exchange-api-table-cb').style.display = 'block';
                document.getElementById('exchange-api-table-pm').style.display = 'none';
            };
            var pmTab = document.createElement('a');
            pmTab.id = "shamra-tab-pm";
            pmTab.classList.add('shamra-tab');
            pmTab.innerText = labels.pm_label;
            pmTab.onclick = function (e) {
		e.preventDefault();
                this.classList.add('active');
                document.getElementById('shamra-tab-cb').classList.remove('active');
                document.getElementById('exchange-api-table-pm').style.display = 'block';
                document.getElementById('exchange-api-table-cb').style.display = 'none';
            };

            tabsDiv.appendChild(cbTab);
            tabsDiv.appendChild(pmTab);
            targetElement.appendChild(tabsDiv);

            var cbTableContainer = document.createElement('div');
            cbTableContainer.id = 'exchange-api-table-cb';
            var cbTable = document.createElement('table');
            cbTable.classList.add('exchange-api-table');
            cbTable.cellSpacing = 0;
            cbTable.appendChild(getCreatedTableHeaders(labels));
            for(var dataElement in data){
                cbTable.appendChild(getCreatedTableRow(data[dataElement] , 'cbn', ApiLink, token));
            }
            cbTableContainer.appendChild(cbTable);
            targetElement.appendChild(cbTableContainer);

            var pmTableContainer = document.createElement('div');
            pmTableContainer.id = 'exchange-api-table-pm';
            pmTableContainer.style.display = 'none';
            var pmTable = document.createElement('table');
            pmTable.classList.add('exchange-api-table');
            pmTable.cellSpacing = 0;
            pmTable.appendChild(getCreatedTableHeaders(labels));
            for(var dataElement in data){
                pmTable.appendChild(getCreatedTableRow(data[dataElement] , 'pm', ApiLink, token));
            }
            pmTableContainer.appendChild(pmTable);
            targetElement.appendChild(pmTableContainer);
        }

        var copyRight = document.createElement('div');
        copyRight.id = 'shamra-copy-right';
        var today = new Date();
        copyRight.appendChild(document.createTextNode('أسعار العملات مقابل الليرة السورية في تاريخ ' + today.getDate() + ' - ' + (today.getMonth() + 1) + ' - ' + today.getFullYear()));
        targetElement.appendChild(copyRight);
        targetElement.style.fontSize = '14px';
    }

    /**
     *  Create the table headers
     */
    function getCreatedTableHeaders(labels) {
        /**
         * <tr>
         *     <th>currency_abv</th>
         *     <th id="exchange-api-table-arrows"></th>
         *     <th>lower_band</th>
         *     <th>upper_band</th>
         * </tr>
         */
        var trHedings = document.createElement('tr');
        var thAbv = document.createElement('th');
        thAbv.appendChild(document.createTextNode(labels.currency_abv));
        var trArrows = document.createElement('th');
        var arrowsSpan = document.createElement('span');
        arrowsSpan.classList.add('exchange-api-table-arrows');
        trArrows.appendChild(arrowsSpan);
        var thLowBnd = document.createElement('th');
        thLowBnd.appendChild(document.createTextNode(labels.lower_band));
        var thHigBnd = document.createElement('th');
        thHigBnd.appendChild(document.createTextNode(labels.upper_band));
        trHedings.appendChild(thAbv);
        trHedings.appendChild(trArrows);
        trHedings.appendChild(thLowBnd);
        trHedings.appendChild(thHigBnd);
        return trHedings;
    }

    /**
     *  Create the table single row
     */
    function getCreatedTableRow(dataRow, source, ApiLink, token) {
        /**
         *  <tr>
         *      <td>abv</td>
         *      <td><span class="exchange-api-table-arrow-*"></span></td>
         *      <td>lowerBand</td>
         *      <td>upperBand</td>
         *      <td><a href="the-link-to-exchange">تصفح</a></td>
         *  </tr>
         */
        var tr = document.createElement('tr');
        tr.setAttribute('title' , dataRow.name);
        var tdAvb = document.createElement('td');
        tdAvb.appendChild(document.createTextNode(dataRow.abv));
        var tdArrows = document.createElement('td');
        var arrowsSpan = document.createElement('span');
        if(source == 'cbn') {
            if (dataRow.cbArrowSameUpDown === 0) {
                arrowsSpan.classList.add("exchange-api-table-arrow-same");
            } else if (dataRow.cbArrowSameUpDown === 1) {
                arrowsSpan.classList.add("exchange-api-table-arrow-up");
            } else {
                arrowsSpan.classList.add("exchange-api-table-arrow-down");
            }
        }else{
            if (dataRow.pmArrowSameUpDown === 0) {
                arrowsSpan.classList.add("exchange-api-table-arrow-same");
            } else if (dataRow.pmArrowSameUpDown === 1) {
                arrowsSpan.classList.add("exchange-api-table-arrow-up");
            } else {
                arrowsSpan.classList.add("exchange-api-table-arrow-down");
            }
        }
        tdArrows.appendChild(arrowsSpan);
        var tdLowBnd = document.createElement('td');
        if(source == 'cbn') {
            tdLowBnd.appendChild(document.createTextNode(dataRow.cbLowerBand));
        }else{
            tdLowBnd.appendChild(document.createTextNode(dataRow.pmLowerBand));
        }
        var tdHigBnd = document.createElement('td');
        if(source == 'cbn') {
            tdHigBnd.appendChild(document.createTextNode(dataRow.cbUpperBand));
        }else{
            tdHigBnd.appendChild(document.createTextNode(dataRow.pmUpperBand));
        }
        var tdLink = document.createElement('td');
        tr.appendChild(tdAvb);
        tr.appendChild(tdArrows);
        tr.appendChild(tdLowBnd);
        tr.appendChild(tdHigBnd);
        tr.onclick = function () {
            var xmlhttp;
            if (window.XMLHttpRequest) {
                xmlhttp = new XMLHttpRequest();
            } else {
                xmlhttp = new ActiveXObject("Microsoft.XMLHTTP");
            }
            xmlhttp.open("GET", ApiLink + '?token=' + token + '&currency_abv=' + dataRow.abv, true);
            xmlhttp.setRequestHeader('Accept' , 'application/json');
            try {
                xmlhttp.send();
            }catch (ex){

            }
            var win = window.open(dataRow.route, '_blank');
            win.focus();
        };
        return tr;
    }

    /**
     * Create style tag to style the inserted table
     */
    function ceateStyleTag() {
        var head = document.head || document.getElementsByTagName('head')[0];
        var fontCario = document.createElement('link');
        fontCario.href = "https://fonts.googleapis.com/css?family=Cairo";
        fontCario.rel = "stylesheet";
        head.appendChild(fontCario);
        var style = document.createElement('style');
        style.type = 'text/css';
        var css = '' +
            '.exchange-api-table {' +
            '   width: 100%;\n' +
            '   border: 1px solid #dddddd;\n' +
            '}' +
            '.exchange-api-table tr:nth-of-type(1) {' +
            '   cursor: auto;\n' +
            '}' +
            '.exchange-api-table tr{' +
            '   cursor: pointer;\n' +
            '   width: 100%;\n' +
            '}' +
            '.exchange-api-table tr:hover td{' +
            '   background-color: #00a550;\n' +
            '   color: #ffffff;\n' +
            '}' +
            '' +
            '.exchange-api-table th, .exchange-api-table td{' +
            '   padding: 8px;\n' +
            '   line-height: 1.42857143;\n' +
            '   vertical-align: top;\n' +
            '   text-align: center;\n' +
            '}' +
            '.exchange-api-table th{' +
            '   background-color: whitesmoke;\n' +
            '   color:orange;\n' +
            '}' +
            '.exchange-api-table td{' +
            '   border-top: 1px solid #ddd;\n' +
            '   color: #00a550;\n' +
            '   font-weight: 900;\n' +
            '   background-color: white;\n' +
            '}' +
            '' +
            '.exchange-api-table-arrows {' +
            '   display: inline-block;\n' +
            '   width: 10px;\n' +
            '   height: 10px;\n' +
            '   margin-top: 4px;\n' +
            '   transform: rotate(45deg);\n' +
            '   background: rgba(255,166,0,1);\n' +
            '   background: -moz-linear-gradient(-45deg, rgba(255,166,0,1) 0%, rgba(255,166,0,1) 41%, rgba(255,255,255,1) 43%, rgba(255,255,255,1) 58%, rgba(255,166,0,1) 60%, rgba(255,166,0,1) 100%);\n' +
            '   background: -webkit-gradient(left top, right bottom, color-stop(0%, rgba(255,166,0,1)), color-stop(41%, rgba(255,166,0,1)), color-stop(43%, rgba(255,255,255,1)), color-stop(58%, rgba(255,255,255,1)), color-stop(60%, rgba(255,166,0,1)), color-stop(100%, rgba(255,166,0,1)));\n' +
            '   background: -webkit-linear-gradient(-45deg, rgba(255,166,0,1) 0%, rgba(255,166,0,1) 41%, rgba(255,255,255,1) 43%, rgba(255,255,255,1) 58%, rgba(255,166,0,1) 60%, rgba(255,166,0,1) 100%);\n' +
            '   background: -o-linear-gradient(-45deg, rgba(255,166,0,1) 0%, rgba(255,166,0,1) 41%, rgba(255,255,255,1) 43%, rgba(255,255,255,1) 58%, rgba(255,166,0,1) 60%, rgba(255,166,0,1) 100%);\n' +
            '   background: -ms-linear-gradient(-45deg, rgba(255,166,0,1) 0%, rgba(255,166,0,1) 41%, rgba(255,255,255,1) 43%, rgba(255,255,255,1) 58%, rgba(255,166,0,1) 60%, rgba(255,166,0,1) 100%);\n' +
            '   background: linear-gradient(135deg, rgba(255,166,0,1) 0%, rgba(255,166,0,1) 41%, rgba(255,255,255,0) 43%, rgba(255,255,255,0) 58%, rgba(255,166,0,1) 60%, rgba(255,166,0,1) 100%);\n' +
            '   filter: progid:DXImageTransform.Microsoft.gradient( startColorstr=\'#ffa600\', endColorstr=\'#ffa600\', GradientType=1 );\n' +
            '   -webkit-transform: rotate(45deg);' +
            '}' +
            '.exchange-api-table-arrow-down {' +
            '   display: inline-block;\n' +
            '   width: 10px;\n' +
            '   height: 10px;\n' +
            '   margin-top: 4px;\n' +
            '   transform: rotate(225deg);\n' +
            '   background: rgba(255,0,0,1);\n' +
            '   background: -moz-linear-gradient(-45deg, rgba(255,0,0,1) 0%, rgba(255,0,0,1) 41%, rgba(255,255,255,0) 43%, rgba(255,255,255,0) 100%);\n' +
            '   background: -webkit-gradient(left top, right bottom, color-stop(0%, rgba(255,0,0,1)), color-stop(41%, rgba(255,0,0,1)), color-stop(43%, rgba(255,255,255,0)), color-stop(100%, rgba(255,255,255,0)));\n' +
            '   background: -webkit-linear-gradient(-45deg, rgba(255,0,0,1) 0%, rgba(255,0,0,1) 41%, rgba(255,255,255,0) 43%, rgba(255,255,255,0) 100%);\n' +
            '   background: -o-linear-gradient(-45deg, rgba(255,0,0,1) 0%, rgba(255,0,0,1) 41%, rgba(255,255,255,0) 43%, rgba(255,255,255,0) 100%);\n' +
            '   background: -ms-linear-gradient(-45deg, rgba(255,0,0,1) 0%, rgba(255,0,0,1) 41%, rgba(255,255,255,0) 43%, rgba(255,255,255,0) 100%);\n' +
            '   background: linear-gradient(135deg, rgba(255,0,0,1) 0%, rgba(255,0,0,1) 41%, rgba(255,255,255,0) 43%, rgba(255,255,255,0) 100%);\n' +
            '   filter: progid:DXImageTransform.Microsoft.gradient( startColorstr=\'#ff0000\', endColorstr=\'#ffffff\', GradientType=1 );' +
            '   -webkit-transform: rotate(225deg);' +
            '}' +
            '' +
            '.exchange-api-table tr:hover .exchange-api-table-arrow-down {' +
            '   background: rgba(255,255,255,1);\n' +
            '   background: -moz-linear-gradient(-45deg, rgba(255,255,255,1) 0%, rgba(255,255,255,1) 41%, rgba(255,255,255,0) 43%, rgba(255,255,255,0) 100%);\n' +
            '   background: -webkit-gradient(left top, right bottom, color-stop(0%, rgba(255,255,255,1)), color-stop(41%, rgba(255,255,255,1)), color-stop(43%, rgba(255,255,255,0)), color-stop(100%, rgba(255,255,255,0)));\n' +
            '   background: -webkit-linear-gradient(-45deg, rgba(255,255,255,1) 0%, rgba(255,255,255,1) 41%, rgba(255,255,255,0) 43%, rgba(255,255,255,0) 100%);\n' +
            '   background: -o-linear-gradient(-45deg, rgba(255,255,255,1) 0%, rgba(255,255,255,1) 41%, rgba(255,255,255,0) 43%, rgba(255,255,255,0) 100%);\n' +
            '   background: -ms-linear-gradient(-45deg, rgba(255,255,255,1) 0%, rgba(255,255,255,1) 41%, rgba(255,255,255,0) 43%, rgba(255,255,255,0) 100%);\n' +
            '   background: linear-gradient(135deg, rgba(255,255,255,1) 0%, rgba(255,255,255,1) 41%, rgba(255,255,255,0) 43%, rgba(255,255,255,0) 100%);\n' +
            '   filter: progid:DXImageTransform.Microsoft.gradient( startColorstr=\'#ff0000\', endColorstr=\'#ffffff\', GradientType=1 );' +
            '}' +
            '' +
            '.exchange-api-table-arrow-up {' +
            '   display: inline-block;\n' +
            '   width: 10px;\n' +
            '   height: 10px;\n' +
            '   margin-top: 4px;\n' +
            '   transform: rotate(45deg);\n' +
            '   background: rgba(0,165,80,1);\n' +
            '   background: -moz-linear-gradient(-45deg, rgba(0,165,80,1) 0%, rgba(0,165,80,1) 42%, rgba(255,255,255,0) 43%, rgba(255,255,255,0) 100%);\n' +
            '   background: -webkit-gradient(left top, right bottom, color-stop(0%, rgba(0,165,80,1)), color-stop(42%, rgba(0,165,80,1)), color-stop(43%, rgba(255,255,255,0)), color-stop(100%, rgba(255,255,255,0)));\n' +
            '   background: -webkit-linear-gradient(-45deg, rgba(0,165,80,1) 0%, rgba(0,165,80,1) 42%, rgba(255,255,255,0) 43%, rgba(255,255,255,0) 100%);\n' +
            '   background: -o-linear-gradient(-45deg, rgba(0,165,80,1) 0%, rgba(0,165,80,1) 42%, rgba(255,255,255,0) 43%, rgba(255,255,255,0) 100%);\n' +
            '   background: -ms-linear-gradient(-45deg, rgba(0,165,80,1) 0%, rgba(0,165,80,1) 42%, rgba(255,255,255,0) 43%, rgba(255,255,255,0) 100%);\n' +
            '   background: linear-gradient(135deg, rgba(0,165,80,1) 0%, rgba(0,165,80,1) 42%, rgba(255,255,255,0) 43%, rgba(255,255,255,0) 100%);\n' +
            '   filter: progid:DXImageTransform.Microsoft.gradient( startColorstr=\'#00a550\', endColorstr=\'#ffffff\', GradientType=1 );' +
            '   -webkit-transform: rotate(45deg);\n' +
            '}' +
            '' +
            '.exchange-api-table tr:hover .exchange-api-table-arrow-up {' +
            '   background: rgba(255,255,255,1);\n' +
            '   background: -moz-linear-gradient(-45deg, rgba(255,255,255,1) 0%, rgba(255,255,255,1) 42%, rgba(255,255,255,0) 43%, rgba(255,255,255,0) 100%);\n' +
            '   background: -webkit-gradient(left top, right bottom, color-stop(0%, rgba(255,255,255,1)), color-stop(42%, rgba(255,255,255,1)), color-stop(43%, rgba(255,255,255,0)), color-stop(100%, rgba(255,255,255,0)));\n' +
            '   background: -webkit-linear-gradient(-45deg, rgba(255,255,255,1) 0%, rgba(255,255,255,1) 42%, rgba(255,255,255,0) 43%, rgba(255,255,255,0) 100%);\n' +
            '   background: -o-linear-gradient(-45deg, rgba(255,255,255,1) 0%, rgba(255,255,255,1) 42%, rgba(255,255,255,0) 43%, rgba(255,255,255,0) 100%);\n' +
            '   background: -ms-linear-gradient(-45deg, rgba(255,255,255,1) 0%, rgba(255,255,255,1) 42%, rgba(255,255,255,0) 43%, rgba(255,255,255,0) 100%);\n' +
            '   background: linear-gradient(135deg, rgba(255,255,255,1) 0%, rgba(255,255,255,1) 42%, rgba(255,255,255,0) 43%, rgba(255,255,255,0) 100%);\n' +
            '   filter: progid:DXImageTransform.Microsoft.gradient( startColorstr=\'#00a550\', endColorstr=\'#ffffff\', GradientType=1 );' +
            '}' +
            '.exchange-api-table-arrow-same {' +
            '   display: inline-block;\n' +
            '   width: 10px;\n' +
            '   height: 10px;\n' +
            '   transform: rotate(45deg);\n' +
            '   margin-top: 4px;\n' +
            '   background: rgba(255,255,255,0);\n' +
            '   background: -moz-linear-gradient(-45deg, rgba(255,255,255,0) 0%, rgba(255,255,255,0) 37%, rgba(255,166,0,1) 38%, rgba(255,166,0,1) 63%, rgba(255,255,255,0) 64%, rgba(255,255,255,0) 100%);\n' +
            '   background: -webkit-gradient(left top, right bottom, color-stop(0%, rgba(255,255,255,0)), color-stop(37%, rgba(255,255,255,0)), color-stop(38%, rgba(255,166,0,1)), color-stop(63%, rgba(255,166,0,1)), color-stop(64%, rgba(255,255,255,0)), color-stop(100%, rgba(255,255,255,0)));\n' +
            '   background: -webkit-linear-gradient(-45deg, rgba(255,255,255,0) 0%, rgba(255,255,255,0) 37%, rgba(255,166,0,1) 38%, rgba(255,166,0,1) 63%, rgba(255,255,255,0) 64%, rgba(255,255,255,0) 100%);\n' +
            '   background: -o-linear-gradient(-45deg, rgba(255,255,255,0) 0%, rgba(255,255,255,0) 37%, rgba(255,166,0,1) 38%, rgba(255,166,0,1) 63%, rgba(255,255,255,0) 64%, rgba(255,255,255,0) 100%);\n' +
            '   background: -ms-linear-gradient(-45deg, rgba(255,255,255,0) 0%, rgba(255,255,255,0) 37%, rgba(255,166,0,1) 38%, rgba(255,166,0,1) 63%, rgba(255,255,255,0) 64%, rgba(255,255,255,0) 100%);\n' +
            '   background: linear-gradient(135deg, rgba(255,255,255,0) 0%, rgba(255,255,255,0) 37%, rgba(255,166,0,1) 38%, rgba(255,166,0,1) 63%, rgba(255,255,255,0) 64%, rgba(255,255,255,0) 100%);\n' +
            '   filter: progid:DXImageTransform.Microsoft.gradient( startColorstr=\'#ffffff\', endColorstr=\'#ffffff\', GradientType=1 );' +
            '   -webkit-transform: rotate(45deg);\n' +
            '}' +
            '' +
            '.exchange-api-table tr:hover .exchange-api-table-arrow-same {' +
            '   background: rgba(255,255,255,0);\n' +
            '   background: -moz-linear-gradient(-45deg, rgba(255,255,255,0) 0%, rgba(255,255,255,0) 37%, rgba(255,255,255,1) 38%, rgba(255,255,255,1) 63%, rgba(255,255,255,0) 64%, rgba(255,255,255,0) 100%);\n' +
            '   background: -webkit-gradient(left top, right bottom, color-stop(0%, rgba(255,255,255,0)), color-stop(37%, rgba(255,255,255,0)), color-stop(38%, rgba(255,255,255,1)), color-stop(63%, rgba(255,255,255,1)), color-stop(64%, rgba(255,255,255,0)), color-stop(100%, rgba(255,255,255,0)));\n' +
            '   background: -webkit-linear-gradient(-45deg, rgba(255,255,255,0) 0%, rgba(255,255,255,0) 37%, rgba(255,255,255,1) 38%, rgba(255,255,255,1) 63%, rgba(255,255,255,0) 64%, rgba(255,255,255,0) 100%);\n' +
            '   background: -o-linear-gradient(-45deg, rgba(255,255,255,0) 0%, rgba(255,255,255,0) 37%, rgba(255,255,255,1) 38%, rgba(255,255,255,1) 63%, rgba(255,255,255,0) 64%, rgba(255,255,255,0) 100%);\n' +
            '   background: -ms-linear-gradient(-45deg, rgba(255,255,255,0) 0%, rgba(255,255,255,0) 37%, rgba(255,255,255,1) 38%, rgba(255,255,255,1) 63%, rgba(255,255,255,0) 64%, rgba(255,255,255,0) 100%);\n' +
            '   background: linear-gradient(135deg, rgba(255,255,255,0) 0%, rgba(255,255,255,0) 37%, rgba(255,255,255,1) 38%, rgba(255,255,255,1) 63%, rgba(255,255,255,0) 64%, rgba(255,255,255,0) 100%);\n' +
            '   filter: progid:DXImageTransform.Microsoft.gradient( startColorstr=\'#ffffff\', endColorstr=\'#ffffff\', GradientType=1 );' +
            '}' +
            '' +
            '#shamra-logo-div {' +
            '   padding-bottom: 5px;' +
            '   text-align: right;' +
            '   padding-right: 1px;' +
            '}' +
            '#shamra-logo-div span{' +
            '   color: #00a550;' +
            '   padding-right: 10px;' +
            '   cursor: pointer;' +
            '}' +
            '#shamra-logo-image{' +
            '   height: 25px;' +
            '   display:inline-block;' +
            '   margin-top: -7px;' +
            '   cursor: pointer;' +
            '}' +
            '\n' +
            '#shamra-tabs-div{' +
            '   width: 100%;\n' +
            '   padding: 0;\n' +
            '   font-weight: 900;\n' +
            '}' +
            '\n' +
            '#shamra-tabs-div{' +
            '   display: flex;' +
            '}' +
            '#shamra-tabs-div a.shamra-tab{' +
            '   width: 50%;' +
            '   display: block;' +
            '   text-align: center;' +
            '   color: #00a550;' +
            '   background-color: whitesmoke;' +
            '   border: 1px solid #dddddd;' +
            '   padding: 1%;' +
            '   text-decoration: none;' +
            '   cursor: pointer;' +
            '}' +
            '\n' +
            '#shamra-tabs-div a.shamra-tab.active{' +
            '   color: #ffffff;' +
            '   background-color: #00a550;' +
            '}' +
            '' +
            '#shamra-copy-right{' +
            '   direction: rtl;' +
            '   background-color: #fff;' +
            '   color: #aaa;' +
            '}';
        style.appendChild(document.createTextNode(css));
        head.appendChild(style);
    }

    function displayErrorBeforeLoad(targetId) {
        window.onload = function () {
            var targetElement = document.getElementById(targetId);
            if(!!targetElement){
                displayError(targetElement);
            }
        }
    }

    function displayErrorBeforeDetectingTarget(targetId) {
        var targetElement = document.getElementById(targetId);
        if(!!targetElement){
            displayError(targetElement);
        }
    }

    function displayError(targetElement) {
        var errorDiv = document.createElement('div');
        errorDiv.id = 'exchange-api-error';
        errorDiv.style.backgroundColor = 'whitesmoke';
        errorDiv.style.padding = '10px';
        errorDiv.style.direction = 'rtl';
        errorDiv.appendChild(document.createTextNode('شمرا عملات . حدث خطأ أثناء التنفيذ، تحقق من منطقة عرض الأخطاء الخاصة بمتصفحك!'))
        targetElement.appendChild(errorDiv);
    }

})();
